use imgui::{TableFlags, Ui};
use thousands::Separable;
use crate::state::{State, Variable};

pub fn draw_main_menu_bar(state: &mut State, ui: &Ui) {
    if let Some(t) = ui.begin_main_menu_bar() {
        if ui.menu_item("Clear") {
            *state = State::default();
        }
        if ui.menu_item("Open") {
            if let Some(f) = rfd::FileDialog::new().add_filter("json", &["json"]).pick_file() {
                let data =  std::fs::read_to_string(f).unwrap_or("}{".to_string());
                let vars: Result<Vec<Variable>, _> = serde_json::from_str(&data);
                match vars {
                    Ok(v) => {
                        *state = State::default();
                        state.variables = v;
                        state.eval_vars();
                    },
                    Err(e) => println!("Error while loading:\n{:#?}", e)
                }
            }
        }
        if ui.menu_item("Save") {
            if let Some(f) = rfd::FileDialog::new().add_filter("json", &["json"]).save_file() {
                if let Err(e) = std::fs::write(f, serde_json::to_string(&state.variables).unwrap()) {
                    println!("Error while saving:\n{:#?}", e);
                }
            }
        }
        t.end();
    }
}

pub fn draw_table(state: &mut State, ui: &Ui) {
    if let Some(t) = ui.begin_table_with_flags("VariableTable", 4, TableFlags::BORDERS | TableFlags::ROW_BG | TableFlags::RESIZABLE) {
        ui.table_setup_column("Name");
        ui.table_setup_column("Value");
        ui.table_setup_column("Expression");
        ui.table_setup_column("Actions");
        ui.table_headers_row();

        let mut to_remove = vec![];
        for v in &state.variables {
            ui.table_next_row();
            ui.table_next_column();
            ui.text(&v.name);
            ui.table_next_column();
            ui.text(v.value.map_or("-".to_string(), |v| v.separate_with_spaces()));
            ui.table_next_column();
            ui.text(&v.expr);
            ui.table_next_column();
            if ui.button(format!("Remove##{}", v.name)) {
                to_remove.push(v.name.clone());
            }
        }
        if !to_remove.is_empty() {
            state.variables.retain(|v| !to_remove.contains(&v.name));
            state.eval_vars();
        }
        t.end();
    }
}
